pub struct EditBlockTool { /* private fields */ }Expand description
Tool for surgical code editing with exact and fuzzy string replacement
Implementations
Sourceimpl EditBlockTool
impl EditBlockTool
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new EditBlockTool using the current working directory as the base path
Sourcepub fn with_base_path(base_path: PathBuf) -> Self
pub fn with_base_path(base_path: PathBuf) -> Self
Create an EditBlockTool with a custom base directory