pub struct FileInfoTool { /* private fields */ }Expand description
Tool for retrieving file metadata
Implementations
Sourceimpl FileInfoTool
impl FileInfoTool
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new tool using the current working directory as the base path.
Equivalent to Default::default().
Panics
Panics if the current working directory cannot be determined.
Use try_new or with_base_path instead.
Sourcepub fn try_new() -> Result<Self>
pub fn try_new() -> Result<Self>
Creates a new tool using the current working directory as the base path.
Returns an error if the current working directory cannot be determined.
Sourcepub fn with_base_path(base_path: PathBuf) -> Self
pub fn with_base_path(base_path: PathBuf) -> Self
Creates a tool with a custom base directory.
All file operations will be constrained to this directory.