pub struct ExportMigrationsTool;Expand description
Exports migrations from the database for transfer to another database
This tool exports migration records that can be imported into another
database using sqlite_import_migrations. This preserves the full
migration history and audit trail.