pub struct ImportMigrationsTool;Expand description
Imports migrations from an export into the database as pending migrations
Use this to transfer migrations from one database to another. Imported
migrations are added as pending and must be applied using sqlite_run_migrations.