Module table

Module table 

Table operation tools

Structs

DescribeTableTool
Tool for getting detailed schema information about a table
ListTablesTool
Tool for listing all tables and views in a database