pub struct ListTablesTool;Expand description
Tool for listing all tables and views in a database
Returns a list of all tables and views, excluding:
- SQLite internal tables (
sqlite_*) - System tables managed by tools (
_*)